@@ -2,10 +2,11 @@
    SDC Base model module
 """
 # coding=utf-8
-# pylint: disable=invalid-name
+# pylint: disable=invalid-name, unused-argument
+import copy
 import json
 from datetime import datetime
-from sqlalchemy import Column, DateTime
+from sqlalchemy import Column, DateTime, Integer, event
 from sqlalchemy.ext.declarative import declarative_base, declared_attr
 from sqlalchemy.orm import query_expression
 
@@ -19,10 +20,11 @@ class Model(Base):
     """
     # pylint: disable=too-few-public-methods, no-member
     __abstract__ = True
+    original = None
 
+    id = Column(Integer, primary_key=True)
     created_at = Column(DateTime)
     updated_at = Column(DateTime)
-    deleted_at = Column(DateTime)
 
     def __init__(self, **kwargs):
         """
@@ -68,3 +70,14 @@ class Model(Base):
             return None
 
         return datetime.strptime(date_string, json_date_format)
+
+@event.listens_for(Model, 'load', restore_load_context=True, propagate=True)
+def receive_load(target, context):
+    """
+        Event listener triggered on first load of model
+
+        args:
+            target: Model instance
+            context: Context data of the model
+     """
+    target.original = copy.deepcopy(target.to_dict())
